"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.flashMessageStyle = void 0;
var react_native_flash_message_1 = require("react-native-flash-message");
var react_native_1 = require("react-native");
var text_1 = __importDefault(require("./text"));
var text_button_1 = __importDefault(require("./text-button"));
var error_symbol_1 = require("./icons/error-symbol");
var clear_symbol_1 = require("./icons/clear-symbol");
var spinner_1 = __importDefault(require("./spinner"));
// 스타일 및 아이콘 설정
var getVariantStyles = function (variant) {
    switch (variant) {
        case 'success':
            return {
                backgroundColor: 'bg-emerald-50',
                textColor: 'emerald-700',
                icon: 'check-circle',
            };
        case 'danger':
            return {
                backgroundColor: 'bg-red-50',
                textColor: 'red-700',
                icon: 'error',
            };
        default:
            return {
                backgroundColor: 'bg-gray-50',
                textColor: 'gray-700',
                icon: 'info',
            };
    }
};
// App.tsx에서 사용할 스타일 설정
exports.flashMessageStyle = {
    backgroundColor: 'transparent', // 배경 투명
    padding: 0,
    margin: 0,
};
var CustomSnackBarContent = function (_a) {
    var message = _a.message, _b = _a.variant, variant = _b === void 0 ? 'default' : _b, _c = _a.loading, loading = _c === void 0 ? false : _c, _d = _a.buttonText, buttonText = _d === void 0 ? '확인' : _d, _e = _a.styleTheme, styleTheme = _e === void 0 ? 'dark' : _e, _f = _a.rightTextButton, rightTextButton = _f === void 0 ? false : _f, thumbnailProps = _a.thumbnailProps, className = _a.className;
    var styles = getVariantStyles(variant);
    var renderIcon = function () {
        if (loading) {
            return (<react_native_1.View>
          <spinner_1.default size="xsmall"/>
        </react_native_1.View>);
        }
        switch (variant) {
            case 'danger':
                return <error_symbol_1.ErrorSymbolIcon />;
            case 'success':
                return <clear_symbol_1.ClearSymbolIcon />;
            default:
                return null;
        }
    };
    if (variant === 'thumbnail' && thumbnailProps) {
        return (<react_native_1.View className={"\n          flex-row items-center justify-between \n          min-h-[60px]\n          p-[16px]\n          ".concat(styleTheme === 'dark' ? 'bg-gray-900' : 'bg-white', "\n          rounded-xl \n          shadow-lg\n          ").concat(className, "\n        ")}>
        <react_native_1.View className={"flex-row items-center flex-1 ".concat(rightTextButton ? 'mr-[8px]' : '')}>
          <react_native_1.Image source={{
                uri: thumbnailProps.imageUrl || '',
            }} className="w-[42px] h-[42px] rounded-[6px]"/>
          <react_native_1.View className="ml-[12px] flex-1">
            <text_1.default face="body" size="large" weight="bold" textColor={styleTheme === 'dark' ? 'white' : 'black'}>
              {thumbnailProps.title}
            </text_1.default>
            <text_1.default face="body" size="small" weight="regular" textColor={styleTheme === 'dark' ? 'gray-400' : 'gray-600'} className="mt-[2px]">
              {thumbnailProps.description}
            </text_1.default>
          </react_native_1.View>
        </react_native_1.View>

        {rightTextButton && (<text_button_1.default text={buttonText} variant="brand" underline={true} onPress={function () { return (0, react_native_flash_message_1.hideMessage)(); }} size="medium"/>)}
      </react_native_1.View>);
    }
    return (<react_native_1.View className={"\n      flex-row items-center justify-between \n      min-h-[60px]\n      p-[16px]\n      ".concat(styleTheme === 'dark' ? 'bg-gray-900' : 'bg-white', "\n      rounded-xl \n      shadow-lg\n      ").concat(className, "\n    ")}>
      <react_native_1.View className="flex-row items-center flex-1">
        {renderIcon()}
        <text_1.default face="body" size="large" weight="regular" textColor={styleTheme === 'dark' ? 'white' : 'black'} className="ml-[6px] flex-1">
          {message}
        </text_1.default>
      </react_native_1.View>

      {rightTextButton && (<text_button_1.default text={buttonText} variant="brand" underline={true} onPress={function () { return (0, react_native_flash_message_1.hideMessage)(); }} size="medium"/>)}
    </react_native_1.View>);
};
var isSnackBarVisible = false;
var showSnackBar = function (_a) {
    var message = _a.message, _b = _a.variant, variant = _b === void 0 ? 'default' : _b, _c = _a.loading, loading = _c === void 0 ? false : _c, _d = _a.buttonText, buttonText = _d === void 0 ? '확인' : _d, _e = _a.duration, duration = _e === void 0 ? 3000 : _e, _f = _a.rightTextButton, rightTextButton = _f === void 0 ? false : _f, _g = _a.styleTheme, styleTheme = _g === void 0 ? 'dark' : _g, thumbnailProps = _a.thumbnailProps, className = _a.className;
    var commonConfig = {
        message: '',
        duration: duration,
        backgroundColor: 'transparent',
        hideStatusBar: false,
        swipeEnabled: true,
        swipeDirection: ['up', 'left', 'right'], // 모든 방향 스와이프 허용
        renderCustomContent: function () { return (<CustomSnackBarContent message={message} variant={variant} styleTheme={styleTheme} loading={loading} buttonText={buttonText} rightTextButton={rightTextButton} thumbnailProps={thumbnailProps} className={className}/>); },
    };
    if (!isSnackBarVisible) {
        isSnackBarVisible = true;
        (0, react_native_flash_message_1.showMessage)(__assign(__assign({}, commonConfig), { onHide: function () {
                isSnackBarVisible = false;
            } }));
    }
    else {
        (0, react_native_flash_message_1.showMessage)(commonConfig);
    }
};
exports.default = showSnackBar;
//# sourceMappingURL=snack-bar.js.map